@@ -9,6 +9,7 @@ from container_service_extension.client.de_cluster_native import DEClusterNative
 from container_service_extension.client.de_cluster_tkg import DEClusterTKG
 from container_service_extension.client.legacy_cluster_native import LegacyClusterNative  # noqa: E501
 from container_service_extension.shared_constants import ClusterEntityKind
+from container_service_extension.shared_constants import CSE_SERVER_RUNTIMES
 
 
 class Cluster:
@@ -25,16 +26,17 @@ class Cluster:
         list_clusters()
 
         :param pyvcloud.vcd.client client: vcd client
-        :param dict cluster_config: cluster configuration
+        :param str k8_runtime:
+
         :return: instance of version specific client side cluster
         """
         api_version = client.get_api_version()
         if float(api_version) < float(vcd_client.ApiVersion.VERSION_35.value):   # noqa: E501
             return LegacyClusterNative(client)
         elif float(api_version) >= float(vcd_client.ApiVersion.VERSION_35.value):  # noqa: E501
-            if k8_runtime == ClusterEntityKind.NATIVE.value or k8_runtime == ClusterEntityKind.TKG_PLUS.value:  # noqa: E501
+            if k8_runtime in CSE_SERVER_RUNTIMES:
                 return DEClusterNative(client)
-            elif k8_runtime == ClusterEntityKind.TKG.value:
+            elif k8_runtime == ClusterEntityKind.TKG_S.value:
                 return DEClusterTKG(client)
             else:
                 return DECluster(client)
