@@ -155,12 +155,11 @@ Example
                             "Note that '--id' flag is applicable for API versions >= 35 only.")  # noqa: E501
 
         client = ctx.obj['client']
-        if client_utils.is_cli_for_tkg_only():
-            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
-                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
-            k8_runtime = shared_constants.ClusterEntityKind.TKG.value
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
         cluster = Cluster(client, k8_runtime=k8_runtime)
         if not client.is_sysadmin() and org is None:
             org = ctx.obj['profiles'].get('org_in_use')
@@ -531,25 +530,34 @@ Examples
     '--native',
     'k8_runtime',
     is_flag=True,
-    flag_value=shared_constants.ClusterEntityKind.NATIVE,
+    flag_value=shared_constants.ClusterEntityKind.NATIVE.value,
     help="should be used with --sample, this flag generates sample yaml for k8 runtime: native"  # noqa: E501
 )
+@click.option(
+    '-k',
+    '--tkg-s',
+    'k8_runtime',
+    is_flag=True,
+    flag_value=shared_constants.ClusterEntityKind.TKG_S.value,
+    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKG service"  # noqa: E501
+)
+@click.option(
+    '-p',
+    '--tkg-plus',
+    'k8_runtime',
+    is_flag=True,
+    hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED),  # noqa: E501
+    flag_value=shared_constants.ClusterEntityKind.TKG_PLUS.value,
+    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKG+"  # noqa: E501
+)
 @click.option(
     '-t',
     '--tkg',
     'k8_runtime',
     is_flag=True,
-    flag_value=shared_constants.ClusterEntityKind.TKG,
-    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKG"  # noqa: E501
-)
-@click.option(
-    '-k',
-    '--tkg-plus',
-    'k8_runtime',
-    is_flag=True,
-    hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED),  # noqa: E501
-    flag_value=shared_constants.ClusterEntityKind.TKG_PLUS,
-    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKG+"  # noqa: E501
+    hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_M_ENABLED),  # noqa: E501
+    flag_value=shared_constants.ClusterEntityKind.TKG_M.value,
+    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKGm"  # noqa: E501
 )
 @click.option(
     '-o',
@@ -592,18 +600,27 @@ def apply(ctx, cluster_config_file_path, generate_sample_config, k8_runtime, out
             raise Exception(msg)
 
         if generate_sample_config:
+            tkg_plus_env_enabled = utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED)  # noqa: E501
+            tkg_m_env_enabled = utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_M_ENABLED)  # noqa: E501
             if not k8_runtime:
                 console_message_printer.general_no_color(ctx.get_help())
-                msg = "with option --sample you must specify either of options: --native or --tkg or --tkg-plus"  # noqa: E501
+                msg = "with option --sample you must specify one of the options: --native or --tkg-s"  # noqa: E501
+                if tkg_plus_env_enabled:
+                    msg += " or --tkg-plus"
+                if tkg_m_env_enabled:
+                    msg += " or --tkg"
                 CLIENT_LOGGER.error(msg)
                 raise Exception(msg)
-            elif k8_runtime == shared_constants.ClusterEntityKind.TKG_PLUS \
-                    and not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED):  # noqa: E501
+            if k8_runtime == shared_constants.ClusterEntityKind.TKG_PLUS.value \
+                    and not tkg_plus_env_enabled:  # noqa: E501
                 raise Exception(f"{shared_constants.ClusterEntityKind.TKG_PLUS.value} not enabled")  # noqa: E501
-            else:
-                sample_cluster_config = client_sample_generator.get_sample_cluster_configuration(output=output, k8_runtime=k8_runtime)  # noqa: E501
-                console_message_printer.general_no_color(sample_cluster_config)
-                return
+            if k8_runtime == shared_constants.ClusterEntityKind.TKG_M.value \
+                    and not tkg_m_env_enabled:  # noqa: E501
+                raise Exception(f"{shared_constants.ClusterEntityKind.TKG_M.value} not enabled")  # noqa: E501
+
+            sample_cluster_config = client_sample_generator.get_sample_cluster_configuration(output=output, k8_runtime=k8_runtime)  # noqa: E501
+            console_message_printer.general_no_color(sample_cluster_config)
+            return
 
         client = ctx.obj['client']
         with open(cluster_config_file_path) as f:
@@ -612,14 +629,13 @@ def apply(ctx, cluster_config_file_path, generate_sample_config, k8_runtime, out
         k8_runtime = cluster_config.get('kind')
         if not k8_runtime:
             raise Exception("Cluster kind missing from the spec.")
-        if client_utils.is_cli_for_tkg_only():
-            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
-                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
-            k8_runtime = shared_constants.ClusterEntityKind.TKG.value
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
         org_name = None
-        if k8_runtime == shared_constants.ClusterEntityKind.TKG.value:
+        if k8_runtime == shared_constants.ClusterEntityKind.TKG_S.value:
             org_name = org
             if not org:
                 org_name = ctx.obj['profiles'].get('org_in_use')
@@ -631,7 +647,7 @@ def apply(ctx, cluster_config_file_path, generate_sample_config, k8_runtime, out
         CLIENT_LOGGER.debug(result)
     except Exception as e:
         stderr(e, ctx)
-        CLIENT_LOGGER.error(str(e))
+        CLIENT_LOGGER.error(str(e), exc_info=True)
 
 
 @cluster_group.command('delete-nfs',
@@ -717,12 +733,11 @@ Examples
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
     try:
         client_utils.cse_restore_session(ctx)
-        if client_utils.is_cli_for_tkg_only():
-            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
-                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
-            k8_runtime = shared_constants.ClusterEntityKind.TKG.value
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
         client = ctx.obj['client']
         cluster = Cluster(client, k8_runtime=k8_runtime)
         if not client.is_sysadmin() and org_name is None:
@@ -799,12 +814,11 @@ Example
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
     try:
         client_utils.cse_restore_session(ctx)
-        if client_utils.is_cli_for_tkg_only():
-            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
-                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
-            k8_runtime = shared_constants.ClusterEntityKind.TKG.value
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
         client = ctx.obj['client']
         cluster = Cluster(client, k8_runtime=k8_runtime)
         if not client.is_sysadmin() and org_name is None:
@@ -881,12 +895,11 @@ Examples:
             raise Exception("Please specify cluster name (or) cluster Id. "
                             "Note that '--id' flag is applicable for API versions >= 35 only.")  # noqa: E501
         client_utils.cse_restore_session(ctx)
-        if client_utils.is_cli_for_tkg_only():
-            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
-                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
-            k8_runtime = shared_constants.ClusterEntityKind.TKG.value
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
         client = ctx.obj['client']
         cluster = Cluster(client, k8_runtime=k8_runtime)
         if not client.is_sysadmin() and org is None:
@@ -964,12 +977,11 @@ Example
             raise Exception("Please specify cluster name (or) cluster Id. "
                             "Note that '--id' flag is applicable for API versions >= 35 only.")  # noqa: E501
         client_utils.cse_restore_session(ctx)
-        if client_utils.is_cli_for_tkg_only():
-            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
-                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
-            k8_runtime = shared_constants.ClusterEntityKind.TKG.value
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
         client = ctx.obj['client']
         cluster = Cluster(client, k8_runtime=k8_runtime)
         if not client.is_sysadmin() and org is None:
