@@ -101,6 +101,13 @@ AVAILABLE_IP_PATH_FRAGMENT = 'availableIpAddresses'
 # NSX-T realized status
 NSXT_GATEWAY_REALIZED_STATUS = 'REALIZED'
 
+# Template fragments
+TKGM_TEMPLATE_NAME_FRAGMENT = 'tkgm'
+
+# TKGM init values
+TKGM_DEFAULT_POD_NETWORK_CIDR = '100.66.0.0/16'
+TKGM_DEFAULT_SERVICE_CIDR = '100.77.0.0/16'
+
 
 @unique
 class NodeType(str, Enum):
@@ -151,6 +158,12 @@ class ScriptFile(str, Enum):
     WORKER_K8S_UPGRADE = 'cluster-upgrade/worker-k8s-upgrade.sh'
 
 
+UPGRADE_SCRIPTS = [ScriptFile.DOCKER_UPGRADE,
+                   ScriptFile.CONTROL_PLANE_CNI_APPLY,
+                   ScriptFile.CONTROL_PLANE_K8S_UPGRADE,
+                   ScriptFile.WORKER_K8S_UPGRADE]
+
+
 @unique
 class LocalTemplateKey(str, Enum):
     """Enumerate the keys that define a template."""
@@ -269,7 +282,7 @@ class CseOperation(Enum):
 
 @unique
 class ClusterMetadataKey(str, Enum):
-    BACKWARD_COMPATIBILE_TEMPLATE_NAME = 'cse.template'
+    BACKWARD_COMPATIBLE_TEMPLATE_NAME = 'cse.template'
     CLUSTER_ID = 'cse.cluster.id'
     CSE_VERSION = 'cse.version'
     CONTROL_PLANE_IP = 'cse.master.ip'
