@@ -1,6 +1,7 @@
 # container-service-extension
 # Copyright (c) 2019 VMware, Inc. All Rights Reserved.
 # SPDX-License-Identifier: BSD-2-Clause
+import time
 
 from pyvcloud.vcd.client import FenceMode
 from pyvcloud.vcd.client import NetworkAdapterType
@@ -17,8 +18,8 @@ from container_service_extension.pyvcloud_utils import get_vdc
 from container_service_extension.pyvcloud_utils import upload_ova_to_catalog
 from container_service_extension.pyvcloud_utils import \
     wait_for_catalog_item_to_resolve
-from container_service_extension.server_constants import ScriptFile, \
-    TemplateBuildKey
+from container_service_extension.server_constants import ScriptFile
+from container_service_extension.server_constants import TemplateBuildKey
 from container_service_extension.utils import download_file
 from container_service_extension.utils import NullPrinter
 from container_service_extension.utils import read_data_file
@@ -37,7 +38,6 @@ def assign_placement_policy_to_template(client, cse_placement_policy,
                                         org_name, logger=NULL_LOGGER,
                                         log_wire=False, msg_update_callback=NullPrinter()): # noqa: E501
 
-    policy = None
     cpm = compute_policy_manager.ComputePolicyManager(client,
                                                       log_wire=log_wire)
     try:
@@ -68,7 +68,7 @@ def assign_placement_policy_to_template(client, cse_placement_policy,
         raise
 
 
-class TemplateBuilder():
+class TemplateBuilder:
     """Builder calls for K8 templates."""
 
     def __init__(self, client, sys_admin_client, build_params, org=None,
@@ -114,6 +114,8 @@ class TemplateBuilder():
         else:
             self.org_name = build_params.get(TemplateBuildKey.ORG_NAME) # noqa: E501
             self.org = get_org(self.client, org_name=self.org_name)
+        # hack for authentication failure issue
+        time.sleep(10)
         if vdc:
             self.vdc = vdc
             self.vdc.get_resource()  # to make sure vdc.resource is populated
@@ -165,7 +167,6 @@ class TemplateBuilder():
         build_params.
 
         :param str item_name: name of the item to delete.
-        :param str item_type
         """
         try:
             self.org.delete_catalog_item(name=self.catalog_name,
@@ -293,7 +294,8 @@ class TemplateBuilder():
         cust_script = read_data_file(
             cust_script_filepath, logger=self.logger,
             msg_update_callback=self.msg_update_callback)
-
+        # hack for authentication failure issue
+        time.sleep(60)
         vs = get_vsphere(self.sys_admin_client, vapp, vm_name,
                          logger=self.logger)
         callback = vgr_callback(
@@ -302,6 +304,8 @@ class TemplateBuilder():
             msg_update_callback=self.msg_update_callback)
         wait_until_tools_ready(vapp, vm_name, vs, callback=callback)
         password_auto = vapp.get_admin_password(vm_name)
+        # hack for authentication failure issue
+        time.sleep(120)
 
         try:
             result = vs.execute_script_in_guest(
@@ -462,8 +466,14 @@ class TemplateBuilder():
 
         self._upload_source_ova()
         vapp = self._create_temp_vapp()
+        # hack for authentication failure issue
+        time.sleep(60)
         self._customize_vm(vapp, self.temp_vm_name)
+        # hack for authentication failure issue
+        time.sleep(60)
         self._capture_temp_vapp(vapp)
+        # hack for authentication failure issue
+        time.sleep(60)
         self._tag_with_cse_placement_policy()
         if not retain_temp_vapp:
             self._delete_temp_vapp()
