@@ -38,6 +38,9 @@ from container_service_extension.server_constants import LocalTemplateKey
 from container_service_extension.server_constants import NodeType
 from container_service_extension.server_constants import ScriptFile
 from container_service_extension.server_constants import SYSTEM_ORG_NAME
+from container_service_extension.shared_constants import CSE_PAGINATION_DEFAULT_PAGE_SIZE  # noqa: E501
+from container_service_extension.shared_constants import CSE_PAGINATION_FIRST_PAGE_NUMBER  # noqa: E501
+from container_service_extension.shared_constants import PaginationKey
 from container_service_extension.shared_constants import RequestKey
 from container_service_extension.telemetry.constants import CseOperation
 from container_service_extension.telemetry.constants import PayloadKey
@@ -97,9 +100,54 @@ class VcdBroker(abstract_broker.AbstractBroker):
 
         return cluster
 
+    def get_clusters_by_page(self, **kwargs):
+        """Get native clusters by page and their relevant metadata.
+
+        :return: paginated dictionary containing list of clusters in
+            that page as values.
+
+        **data: Optional
+            Optional data and default values: org_name=None, ovdc_name=None
+        **telemetry: Optional
+        """
+        data = kwargs.get(KwargKey.DATA, {})
+        page_number = kwargs.get('page_number',
+                                 CSE_PAGINATION_FIRST_PAGE_NUMBER)
+        page_size = kwargs.get('page_size',
+                               CSE_PAGINATION_DEFAULT_PAGE_SIZE)
+
+        defaults = {
+            RequestKey.ORG_NAME: None,
+            RequestKey.OVDC_NAME: None,
+        }
+        validated_data = {**defaults, **data}
+
+        if kwargs.get(KwargKey.TELEMETRY, True):
+            # Record the data for telemetry
+            record_user_action_details(
+                cse_operation=CseOperation.CLUSTER_LIST,
+                cse_params=copy.deepcopy(validated_data))
+
+        # "raw clusters" do not have well-defined cluster data keys
+        raw_clusters_info = get_all_clusters(
+            self.context.client,
+            org_name=validated_data[RequestKey.ORG_NAME],
+            ovdc_name=validated_data[RequestKey.OVDC_NAME],
+            page_number=page_number,
+            page_size=page_size)
+
+        raw_clusters_info[PaginationKey.VALUES] = \
+            _extract_cse_cluster_list_info(self.context.sysadmin_client,
+                                           raw_clusters_info[PaginationKey.VALUES])  # noqa: E501
+        return raw_clusters_info
+
     def list_clusters(self, **kwargs):
         """List all native clusters and their relevant metadata.
 
+        :return: a list of all clusters if 'page_number' or 'page_size' are
+            not part of the kwargs. If 'page_number' or 'page_size' is present,
+            a paginated response is returned.
+
         Common broker function that validates data for the 'list clusters'
         operation and returns a list of cluster data.
 
@@ -108,6 +156,7 @@ class VcdBroker(abstract_broker.AbstractBroker):
         **telemetry: Optional
         """
         data = kwargs.get(KwargKey.DATA, {})
+
         defaults = {
             RequestKey.ORG_NAME: None,
             RequestKey.OVDC_NAME: None
@@ -126,26 +175,8 @@ class VcdBroker(abstract_broker.AbstractBroker):
             org_name=validated_data[RequestKey.ORG_NAME],
             ovdc_name=validated_data[RequestKey.OVDC_NAME])
 
-        clusters = []
-        for c in raw_clusters:
-            org_name = vcd_utils.get_org_name_from_ovdc_id(
-                self.context.sysadmin_client, c['vdc_id'])
-            clusters.append({
-                'name': c['name'],
-                'control_plane_ip': c['leader_endpoint'],
-                'template_name': c.get('template_name'),
-                'template_revision': c.get('template_revision'),
-                'k8s_type': c.get('kubernetes'),
-                'k8s_version': c.get('kubernetes_version'),
-                'VMs': c['number_of_vms'],
-                'vdc': c['vdc_name'],
-                'status': c['status'],
-                'vdc_id': c['vdc_id'],
-                'org_name': org_name,
-                'owner_name': c['owner_name'],
-                K8S_PROVIDER_KEY: K8sProvider.NATIVE
-            })
-        return clusters
+        return _extract_cse_cluster_list_info(self.context.sysadmin_client,
+                                              raw_clusters)
 
     def get_cluster_config(self, **kwargs):
         """Get the cluster's kube config contents.
@@ -1368,7 +1399,7 @@ def _drain_nodes(sysadmin_client: vcd_client.Client, vapp_href, node_names,
     script = "#!/usr/bin/env bash\n"
     for node_name in node_names:
         script += f"kubectl drain {node_name} " \
-                  f"--ignore-daemonsets --timeout=60s --delete-local-data\n"
+                  f"--force --ignore-daemonsets --timeout=60s --delete-local-data\n"  # noqa: E501
 
     try:
         vapp = vcd_vapp.VApp(sysadmin_client, href=vapp_href)
@@ -1481,6 +1512,8 @@ def _get_nfs_exports(sysadmin_client: vcd_client.Client, ip, vapp, vm_name):
     :return: (List): List of exports
     """
     script = f"#!/usr/bin/env bash\nshowmount -e {ip}"
+    # since the vapp is already running at this point in the code, there
+    # is no need to add additional sleep.
     result = _execute_script_in_nodes(sysadmin_client, vapp=vapp,
                                       node_names=[vm_name], script=script,
                                       check_tools=False)
@@ -1533,12 +1566,26 @@ def _update_cluster_dict_with_node_info(client, cluster):
 
 
 def get_all_clusters(client, cluster_name=None, cluster_id=None,
-                     org_name=None, ovdc_name=None, fetch_details=False):
+                     org_name=None, ovdc_name=None, fetch_details=False,
+                     page_number=None, page_size=None):
     """Get list of dictionaries containing data for each visible cluster.
 
+    :param str cluster_name: name of the cluster to search for
+    :param str cluster_id: id of the cluster to search for
+    :param str org_name: restrict the cluster search to a specific org with
+        name org_name
+    :param str ovdc_name: restrict the cluster search to a specific ovdc with
+        name ovdc_name
     :param bool fetch_details: If set, will fetch additional information about
         each individual cluster e.g. network_name, org_name, org_href, list of
         control_plane/worker/nfs nodes and their ips.
+    :param int page_number: return clusters in a specific page number
+    :param int page_size: return page_size results
+    :return: list of clusters if page_number is not specified. Else, a dict
+        containing cluster list and paginaion information
+
+    NOTE: if page_number is provided, the return type will be a dictionary
+        containing pagination information along with the cluster list
     TODO define these cluster data dictionary keys better:
         'name', 'vapp_id', 'vapp_href', 'vdc_name', 'vdc_href', 'vdc_id',
         'leader_endpoint', 'master_nodes', 'nodes', 'nfs_nodes',
@@ -1571,7 +1618,9 @@ def get_all_clusters(client, cluster_name=None, cluster_id=None,
                f',metadata:{ClusterMetadataKey.CSE_VERSION}'
                f',metadata:{ClusterMetadataKey.TEMPLATE_NAME}'
                f',metadata:{ClusterMetadataKey.TEMPLATE_REVISION}'
-               f',metadata:{ClusterMetadataKey.OS}')
+               f',metadata:{ClusterMetadataKey.OS}',
+        page=page_number,
+        page_size=page_size)
     q2 = client.get_typed_query(
         resource_type,
         query_result_format=vcd_client.QueryResultFormat.ID_RECORDS,
@@ -1580,7 +1629,9 @@ def get_all_clusters(client, cluster_name=None, cluster_id=None,
                f',metadata:{ClusterMetadataKey.KUBERNETES}'
                f',metadata:{ClusterMetadataKey.KUBERNETES_VERSION}'
                f',metadata:{ClusterMetadataKey.CNI}'
-               f',metadata:{ClusterMetadataKey.CNI_VERSION}')
+               f',metadata:{ClusterMetadataKey.CNI_VERSION}',
+        page=page_number,
+        page_size=page_size)
 
     metadata_key_to_cluster_key = {
         ClusterMetadataKey.CLUSTER_ID: 'cluster_id',
@@ -1597,7 +1648,17 @@ def get_all_clusters(client, cluster_name=None, cluster_id=None,
     }
 
     clusters = {}
-    for record in q.execute():
+    cluster_list = []
+    result_total = None
+    if page_number:
+        # since page_number is provided during query creation, the return type
+        # from pyvcloud will be a dict containing pagination information
+        clusters_info = q.execute()
+        cluster_list = clusters_info['values']
+        result_total = int(clusters_info.get('resultTotal'))
+    else:
+        cluster_list = q.execute()
+    for record in cluster_list:
         vapp_id = record.get('id').split(':')[-1]
         vdc_id = record.get('vdc').split(':')[-1]
         vapp_href = f'{client.get_api_uri()}/vApp/vapp-{vapp_id}'
@@ -1637,30 +1698,43 @@ def get_all_clusters(client, cluster_name=None, cluster_id=None,
                 if element.Key in metadata_key_to_cluster_key:
                     clusters[vapp_id][metadata_key_to_cluster_key[element.Key]] = str(element.TypedValue.Value) # noqa: E501
 
+    if page_number:
+        # since page_number is provided during query creation, the return type
+        # from pyvcloud will be a dict containing pagination information
+        clusters_info = q2.execute()
+        cluster_list = clusters_info['values']
+        result_total = int(clusters_info.get('resultTotal'))
+    else:
+        cluster_list = q2.execute()
     # api query can fetch only 8 metadata at a time
     # since we have more than 8 metadata, we need to use 2 queries
-    for record in q2.execute():
+    for record in cluster_list:
         vapp_id = record.get('id').split(':')[-1]
         if hasattr(record, 'Metadata'):
             for element in record.Metadata.MetadataEntry:
                 if element.Key in metadata_key_to_cluster_key:
                     clusters[vapp_id][metadata_key_to_cluster_key[element.Key]] = str(element.TypedValue.Value) # noqa: E501
 
-    if not fetch_details:
-        return list(clusters.values())
+    if fetch_details:
+        for cluster in clusters.values():
+            vapp = vcd_vapp.VApp(client, href=cluster['vapp_href'])
+            cluster['network_name'] = \
+                vcd_utils.get_parent_network_name_of_vapp(vapp)
+            cluster['storage_profile_name'] = \
+                vcd_utils.get_storage_profile_name_of_first_vm_in_vapp(vapp)
+            _update_cluster_dict_with_node_info(client, cluster)
+            if client.is_sysadmin():
+                cluster['org_name'] = \
+                    vcd_utils.get_org_name_from_ovdc_id(client, cluster['vdc_id'])  # noqa: E501
+                cluster['org_href'] = \
+                    vcd_utils.get_org_href_from_ovdc_id(client, cluster['vdc_id'])  # noqa: E501
 
-    for cluster in clusters.values():
-        vapp = vcd_vapp.VApp(client, href=cluster['vapp_href'])
-        cluster['network_name'] = \
-            vcd_utils.get_parent_network_name_of_vapp(vapp)
-        cluster['storage_profile_name'] = \
-            vcd_utils.get_storage_profile_name_of_first_vm_in_vapp(vapp)
-        _update_cluster_dict_with_node_info(client, cluster)
-        if client.is_sysadmin():
-            cluster['org_name'] = \
-                vcd_utils.get_org_name_from_ovdc_id(client, cluster['vdc_id'])
-            cluster['org_href'] = \
-                vcd_utils.get_org_href_from_ovdc_id(client, cluster['vdc_id'])
+    if page_number:
+        # return pagination details as well
+        return {
+            PaginationKey.VALUES: list(clusters.values()),
+            PaginationKey.RESULT_TOTAL: result_total
+        }
 
     return list(clusters.values())
 
@@ -1792,7 +1866,7 @@ def _add_nodes(sysadmin_client, num_nodes, node_type, org, vdc, vapp,
                         script_filepath, logger=LOGGER)
                     exec_results = _execute_script_in_nodes(
                         sysadmin_client, vapp=vapp, node_names=[vm_name],
-                        script=script)
+                        script=script, use_authentication_sleep=True)
                     errors = _get_script_execution_errors(exec_results)
                     if errors:
                         raise e.ScriptExecutionError(
@@ -1808,6 +1882,30 @@ def _add_nodes(sysadmin_client, num_nodes, node_type, org, vdc, vapp,
         return {'task': task, 'specs': specs}
 
 
+def _extract_cse_cluster_list_info(sysadmin_client: vcd_client.Client,
+                                   raw_clusters: list) -> list:
+    clusters = []
+    for c in raw_clusters:
+        org_name = vcd_utils.get_org_name_from_ovdc_id(sysadmin_client,
+                                                       c['vdc_id'])
+        clusters.append({
+            'name': c['name'],
+            'control_plane_ip': c['leader_endpoint'],
+            'template_name': c.get('template_name'),
+            'template_revision': c.get('template_revision'),
+            'k8s_type': c.get('kubernetes'),
+            'k8s_version': c.get('kubernetes_version'),
+            'VMs': c['number_of_vms'],
+            'vdc': c['vdc_name'],
+            'status': c['status'],
+            'vdc_id': c['vdc_id'],
+            'org_name': org_name,
+            'owner_name': c['owner_name'],
+            K8S_PROVIDER_KEY: K8sProvider.NATIVE
+        })
+    return clusters
+
+
 def _get_node_names(vapp, node_type):
     return [vm.get('name') for vm in vapp.get_all_vms() if vm.get('name').startswith(node_type)] # noqa: E501
 
@@ -1833,6 +1931,8 @@ def _get_control_plane_ip(sysadmin_client: vcd_client.Client, vapp):
              "ip route get 1 | awk '{print $NF;exit}'\n" \
 
     node_names = _get_node_names(vapp, NodeType.CONTROL_PLANE)
+    # Since the VM is expected to be running at this point in the
+    # code, there is no need to add the additional sleep
     result = _execute_script_in_nodes(sysadmin_client, vapp=vapp,
                                       node_names=node_names, script=script,
                                       check_tools=False)
@@ -1858,7 +1958,8 @@ def _init_cluster(sysadmin_client: vcd_client.Client, vapp, template_name,
         script = utils.read_data_file(script_filepath, logger=LOGGER)
         node_names = _get_node_names(vapp, NodeType.CONTROL_PLANE)
         result = _execute_script_in_nodes(sysadmin_client, vapp=vapp,
-                                          node_names=node_names, script=script)
+                                          node_names=node_names, script=script,
+                                          use_authentication_sleep=True)
         errors = _get_script_execution_errors(result)
         if errors:
             raise e.ScriptExecutionError(
@@ -1880,6 +1981,8 @@ def _join_cluster(sysadmin_client: vcd_client.Client, vapp, template_name,
                  "kubeadm token create\n" \
                  "ip route get 1 | awk '{print $NF;exit}'\n"
         node_names = _get_node_names(vapp, NodeType.CONTROL_PLANE)
+        # Since the control-plane VM is already running at this point in the
+        # code, there is no need to add the additional sleep
         control_plane_result = _execute_script_in_nodes(sysadmin_client,
                                                         vapp=vapp,
                                                         node_names=node_names,
@@ -1899,9 +2002,11 @@ def _join_cluster(sysadmin_client: vcd_client.Client, vapp, template_name,
                                                       ScriptFile.NODE)
         tmp_script = utils.read_data_file(tmp_script_filepath, logger=LOGGER)
         script = tmp_script.format(token=init_info[0], ip=init_info[1])
-        worker_results = _execute_script_in_nodes(sysadmin_client, vapp=vapp,
+        worker_results = _execute_script_in_nodes(sysadmin_client,
+                                                  vapp=vapp,
                                                   node_names=node_names,
-                                                  script=script)
+                                                  script=script,
+                                                  use_authentication_sleep=True)  # noqa: E501
         errors = _get_script_execution_errors(worker_results)
         if errors:
             raise e.ScriptExecutionError("Join cluster script execution "
@@ -1942,9 +2047,13 @@ def _wait_until_ready_to_exec(vs, vm, password, tries=30):
 
 def _execute_script_in_nodes(sysadmin_client: vcd_client.Client,
                              vapp, node_names, script,
-                             check_tools=True, wait=True):
+                             check_tools=True, wait=True,
+                             use_authentication_sleep=False):
     vcd_utils.raise_error_if_user_not_from_system_org(sysadmin_client)
     all_results = []
+    if use_authentication_sleep:
+        # hack for authentication failure issue
+        time.sleep(150)
     for node_name in node_names:
         try:
             LOGGER.debug(f"will try to execute script on {node_name}:\n"
@@ -2009,6 +2118,8 @@ def _run_script_in_nodes(sysadmin_client: vcd_client.Client, vapp_href,
 
     # when is tools checking necessary?
     vapp = vcd_vapp.VApp(sysadmin_client, href=vapp_href)
+    # Since the VM is expected to be running at this point in the
+    # code, there is no need to add the additional sleep
     results = _execute_script_in_nodes(sysadmin_client,
                                        vapp=vapp,
                                        node_names=node_names,
